from typing import Dict

DEFAULT_CONFIG: Dict = {
    "kwargs": {"actor": "actor", "trigger": "trigger", "target": "target"}
}
